==> openshift-model-miscellaneous-6.8.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/cncf/cni/v1/NetworkAttachmentDefinitionSpecFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.cncf.cni.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NetworkAttachmentDefinitionSpecFluent<A extends NetworkAttachmentDefinitionSpecFluent<A>> extends BaseFluent<A>{
  public NetworkAttachmentDefinitionSpecFluent() {
  }
  public NetworkAttachmentDefinitionSpecFluent(NetworkAttachmentDefinitionSpec instance) {
    instance = (instance != null ? instance : new NetworkAttachmentDefinitionSpec());

    if (instance != null) {
      this.withConfig(instance.getConfig());
      this.withConfig(instance.getConfig());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String config;
  private Map<String,Object> additionalProperties;
  public String getConfig() {
    return this.config;
  }
  public A withConfig(String config) {
    this.config=config; return (A) this;
  }
  public boolean hasConfig() {
    return this.config != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkAttachmentDefinitionSpecFluent that = (NetworkAttachmentDefinitionSpecFluent) o;
    if (!java.util.Objects.equals(config, that.config)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(config,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (config != null) { sb.append("config:"); sb.append(config + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-miscellaneous-6.9.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/cncf/cni/v1/NetworkAttachmentDefinitionSpecFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.cncf.cni.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class NetworkAttachmentDefinitionSpecFluent<A extends NetworkAttachmentDefinitionSpecFluent<A>> extends BaseFluent<A>{
  public NetworkAttachmentDefinitionSpecFluent() {
  }
  
  public NetworkAttachmentDefinitionSpecFluent(NetworkAttachmentDefinitionSpec instance) {
    this.copyInstance(instance);
  }
  private String config;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(NetworkAttachmentDefinitionSpec instance) {
    instance = (instance != null ? instance : new NetworkAttachmentDefinitionSpec());
  
    if (instance != null) {
        this.withConfig(instance.getConfig());
        this.withConfig(instance.getConfig());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getConfig() {
    return this.config;
  }
  
  public A withConfig(String config) {
    this.config=config; return (A) this;
  }
  
  public boolean hasConfig() {
    return this.config != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkAttachmentDefinitionSpecFluent that = (NetworkAttachmentDefinitionSpecFluent) o;
    if (!java.util.Objects.equals(config, that.config)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(config,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (config != null) { sb.append("config:"); sb.append(config + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
